@@ -49,28 +49,26 @@ class Entry(object):
         return d
 
     def empty_data(self):
-        data = ''
-        for field in self.collection.settings['fields']:
-            if not field.get('help', None) is None:
-                data += "# {name} ({type}): {help}\n".format(**field)
-            t = field['type']
-            if field.get('default', None):
-                data += "{name}: '{default}'\n".format(**field)
-            elif t == 'string':
-                data += "{name}: ''\n".format(**field)
-            elif t == 'text':
-                data += "{name}: |\n    .\n".format(**field)
-            elif t == 'integer':
-                data += "{name}: 0\n".format(**field)
-            elif t == 'float':
-                data += "{name}: 0.0\n".format(**field)
-            elif t == 'decimal':
-                data += "{name}: 0.00\n".format(**field)
-            elif t == 'list':
-                data += "{name}: []\n".format(**field)
+        data = self.collection.yaml.load("{}")
+        for name, field in self.collection.fields.items():
+            if field.field.get('default', None):
+                data[name] = field.field['default']
             else:
-                data += "{name}: \n".format(**field)
-        return self.collection.yaml.load(data)
+                data[name] = field.empty()
+            if field.field.get('help', None) is not None:
+                comment = "# {name} ({type}): {help}\n".format(**field.field)
+                try:
+                    data.yaml_set_comment_before_after_key(
+                        key=name,
+                        before=comment,
+                        indent=0
+                    )
+                except AttributeError:
+                    logging.warning(
+                        "Not adding comments because they are not"
+                        "supported by the yaml loader."
+                    )
+        return data
 
     @property
     def yaml_data(self):
@@ -81,8 +79,9 @@ class Entry(object):
         for field in self.collection.settings['fields']:
             if field['type'] == 'decimal':
                 v = to_dump.get(field['name'], '')
-                if v:
+                if v is not None:
                     to_dump[field['name']] = str(v)
+
         s_io = io.StringIO()
         self.collection.yaml.dump(to_dump, s_io)
         return s_io.getvalue()
@@ -119,6 +118,19 @@ class Entry(object):
         except jinja2.exceptions.TemplateSyntaxError as e:
             raise TemplatingError('Template Syntax Error: ' + str(e))
 
+    def auto(self):
+        """
+        Update all fields of this entry, as required by the field settings.
+
+        This is called by the reference client before an edit, so that
+        the user can make further changes.
+
+        Note that the stored file is not changed: if you need it you
+        need to save the entry yourself.
+        """
+        for name, field in self.collection.fields.items():
+            self.data[name] = field.auto(self.data.get(name, None))
+
 
 class Collection(object):
     """
@@ -136,6 +148,7 @@ class Collection(object):
         self.itemdir = os.path.join(self.basedir, itemdir)
         self.yaml = ruamel.yaml.YAML()
         self.yaml.preserve_quotes = True
+        self.yaml.typ = 'rt'
         try:
             with open(os.path.join(self.basedir, 'settings.yaml')) as fp:
                 self.settings = self.yaml.load(fp)
@@ -330,11 +343,17 @@ class Collection(object):
         for field in self.indexed_fields:
             queryparser.add_prefix(field['name'], field['prefix'])
 
-        query = queryparser.parse_query(querystring, self.PARSER_FLAGS)
+        if querystring == '*':
+            query = xapian.Query.MatchAll
+        else:
+            query = queryparser.parse_query(querystring, self.PARSER_FLAGS)
 
         self._enquire = xapian.Enquire(cache)
         self._enquire.set_query(query)
 
+        if not sort_by and self.settings.get('default_sort', False):
+            sort_by = self.settings['default_sort']
+
         if sort_by:
             keymaker = xapian.MultiValueKeyMaker()
             for k in sort_by:
@@ -370,6 +389,13 @@ class Collection(object):
             offset += pagesize
 
     def get_all_documents(self):
+        """
+        Yield all documents in the collection.
+
+        Note that the results can't be sorted, even if the collection
+        has a default_sort; if you need sorted values you need to use a
+        regular search with a query of '*'
+        """
         cache = self._get_cache()
         postlist = cache.postlist("")
         for post in postlist:
