@@ -1,3 +1,4 @@
+import datetime
 import logging
 import os.path
 import shutil
@@ -117,6 +118,13 @@ class testEntries(unittest.TestCase):
         self.assertIn("name: ''", entry.yaml_data)
         self.assertIn('quantity: 0', entry.yaml_data)
 
+    def test_update_entry(self):
+        eid = '11189ee47ddf4796b718a483b379f976'
+        entry = self.collection.entry_from_eid(eid)
+        old_data = entry.data.copy()
+        entry.auto()
+        self.assertEqual(old_data, entry.data)
+
 
 class testEmptyCollection(unittest.TestCase):
     def setUp(self):
@@ -130,8 +138,9 @@ class testEmptyCollection(unittest.TestCase):
     def test_loaded(self):
         self.assertEqual(self.collection.settings, {})
 
-        self.collection.update_cache()
+        indexed = self.collection.update_cache()
         self.assertIsNotNone(self.collection.stemmer)
+        self.assertEqual(indexed, 0)
 
 
 class testSimpleCollection(unittest.TestCase):
@@ -151,8 +160,9 @@ class testSimpleCollection(unittest.TestCase):
         self.assertEqual(len(self.collection.settings['fields']), 7)
         self.assertEqual(len(self.collection.indexed_fields), 3)
 
-        self.collection.update_cache()
+        indexed = self.collection.update_cache()
         self.assertIsNotNone(self.collection.stemmer)
+        self.assertEqual(indexed, 3)
 
     def test_full_search(self):
         self.collection.start_search('Item')
@@ -221,7 +231,8 @@ class testSimpleCollection(unittest.TestCase):
         self.assertIn("non_existing_file", cm.output[0])
 
     def test_index_reset(self):
-        self.collection.update_cache(reset=True)
+        indexed = self.collection.update_cache(reset=True)
+        self.assertEqual(indexed, 3)
 
     def test_get_entry_missing_eid(self):
         entry = self.collection.entry_from_eid('this is not an eid')
@@ -258,6 +269,18 @@ class testSimpleCollection(unittest.TestCase):
             ).data['position']
         )
 
+    def test_representation_decimal(self):
+        entry = self.collection.entry_from_eid(
+            '085682ed6792499da3ab9aebd683c011'
+        )
+        data = ruamel.yaml.safe_load(entry.yaml_data)
+        self.assertEqual(data['cost'], '1.99')
+
+        fname = 'tests/data/simple/items/' + \
+            '085682ed-6792-499d-a3ab-9aebd683c011.yaml'
+        with open(fname, 'r') as fp:
+            self.assertEqual(entry.yaml_data, fp.read())
+
 
 class testComplexCollection(unittest.TestCase):
     def setUp(self):
@@ -274,12 +297,13 @@ class testComplexCollection(unittest.TestCase):
             self.collection.settings['name'],
             "Fully featured lesana collection",
         )
-        self.assertEqual(len(self.collection.settings['fields']), 9)
+        self.assertEqual(len(self.collection.settings['fields']), 14)
         self.assertIsNotNone(self.collection.stemmer)
-        self.assertEqual(len(self.collection.indexed_fields), 7)
+        self.assertEqual(len(self.collection.indexed_fields), 8)
 
     def test_index(self):
-        self.collection.update_cache()
+        indexed = self.collection.update_cache()
+        self.assertEqual(indexed, 9)
 
     def test_indexing_list(self):
         self.collection.update_cache(['73097121f1874a6ea2f927db7dc4f11e.yaml'])
@@ -301,6 +325,15 @@ class testComplexCollection(unittest.TestCase):
         self.assertIn("name: ''", entry.yaml_data)
         self.assertIn('with_default', entry.yaml_data)
         self.assertIn('amount: 0', entry.yaml_data)
+        self.assertIn("tags: []", entry.yaml_data)
+        self.assertIn("exists:\n", entry.yaml_data)
+        # we just check that created starts with a date and ends with
+        # the utc timezone to keep the regex short and manageable
+        self.assertRegex(
+            entry.yaml_data,
+            r"created: [\d]{4,4}-[\d]{2,2}-[\d]{2,2} .*\+00\:00"
+        )
+        self.assertIn("epoch:\n", entry.yaml_data)
 
     def test_load_field_loaders(self):
         # Check that all fields have been loaded, with the right types
@@ -335,6 +368,13 @@ class testComplexCollection(unittest.TestCase):
         with open(fname, 'r') as fp:
             self.assertEqual(e.yaml_data, fp.read())
 
+    def test_data_is_stored_as_written_on_file_with_apices(self):
+        e = self.collection.entry_from_eid('8e9fa1ed3c1b4a30a6be7a98eda0cfa7')
+        fname = 'tests/data/complex/items/' + \
+            '8e9fa1ed3c1b4a30a6be7a98eda0cfa7.yaml'
+        with open(fname, 'r') as fp:
+            self.assertEqual(e.yaml_data, fp.read())
+
     def test_sorted_search(self):
         # search in ascending order
         self.collection.start_search('Amount', sort_by=['amount'])
@@ -356,6 +396,53 @@ class testComplexCollection(unittest.TestCase):
         self.assertEqual(matches[2].data['amount'], 10)
         self.assertEqual(matches[3].data['amount'], 2)
 
+    def test_default_sorted_search(self):
+        # search in ascending order
+        self.collection.start_search('Amount')
+        res = self.collection.get_search_results()
+        matches = list(res)
+        self.assertEqual(len(matches), 4)
+        print([m.data['order'] for m in matches])
+        self.assertEqual(matches[0].data['order'], None)
+        self.assertEqual(matches[1].data['order'], 'alpha')
+        self.assertEqual(matches[2].data['order'], 'charlie')
+        self.assertEqual(matches[3].data['order'], 'zucchini')
+
+    def test_search_all_documents_default_sort(self):
+        self.collection.start_search('*')
+        res = self.collection.get_search_results()
+        matches = list(res)
+        self.assertEqual(len(matches), 9)
+        for i in range(5):
+            self.assertEqual(matches[i].data['order'], None)
+        self.assertEqual(matches[5].data['order'], 'alpha')
+        self.assertEqual(matches[6].data['order'], 'charlie')
+        self.assertEqual(matches[7].data['order'], 'delta')
+        self.assertEqual(matches[8].data['order'], 'zucchini')
+
+    def test_update_entry(self):
+        eid = '5084bc6e94f24dc6976629282ef30419'
+        entry = self.collection.entry_from_eid(eid)
+        # we keep the old data, and check that the updated field is
+        # empty and the version field is 0
+        old_data = entry.data.copy()
+        self.assertEqual(entry.data['updated'], None)
+        self.assertEqual(entry.data['version'], 0)
+
+        entry.auto()
+
+        # after the update, fields that were not supposed to be updated
+        # are equal to what they were before, while updated has been
+        # changed to a datetime in this year (we don't check too deeply
+        # to avoid breaking tests too often with race conditions) and
+        # version has grown to 2.
+        for field in ('created', 'epoch'):
+            self.assertEqual(old_data[field], entry.data[field])
+        now = datetime.datetime.now(datetime.timezone.utc)
+        self.assertIsInstance(entry.data['updated'], datetime.datetime)
+        self.assertEqual(entry.data['updated'].year, now.year)
+        self.assertEqual(entry.data['version'], 2)
+
 
 class testCollectionWithErrors(unittest.TestCase):
     def setUp(self):
